@@ -6,18 +6,22 @@ test_that("download_observations and check_for_newer_data work", {
   skip_on_cran() # these download checks take a while to run
   expect_error(download_observations(portal_data_path, version = "1.20.0"), NA)
   expect_true(check_for_newer_data(portal_data_path))
+  httptest::without_internet({
+    expect_false(check_for_newer_data(portal_data_path))
+  })
   unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
 
   expect_error(download_observations(portal_data_path, version = "1.6"), NA)
   expect_true(check_for_newer_data(portal_data_path))
   unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
+  expect_true(check_for_newer_data(portal_data_path))
 
   expect_error(download_observations(portal_data_path, version = "1.5.9"))
-  unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
+  expect_error(download_observations(portal_data_path, version = "1.000.0"))
 
   expect_error(download_observations(portal_data_path, from_zenodo = TRUE), NA)
   expect_false(check_for_newer_data(portal_data_path))
-  unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
+  #unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
 
   expect_error(download_observations(portal_data_path), NA)
   expect_false(check_for_newer_data(portal_data_path))
@@ -30,7 +34,7 @@ test_that("load_rodent_data downloads data if missing", {
 })
 
 test_that("looking up data versions handle lack of a network connection", {
-  without_internet({
+  httptest::without_internet({
     #expect_null(get_data_versions(from_zenodo = TRUE, halt_on_error = FALSE))
     #expect_error(get_data_versions(from_zenodo = TRUE, halt_on_error = TRUE),
     #             "^GET https://zenodo.org/record/1215988$")
@@ -85,3 +89,29 @@ test_that("load_ant_data works", {
                  "plots_table"))
 })
 
+test_that("default data path functions work if unset", {
+  Sys.unsetenv("PORTALR_DATA_PATH")
+  expect_warning(result <- check_default_data_path(MESSAGE_FUN = warning),
+                 "You don't appear to have a defined location for storing Portal data.")
+  expect_false(result)
+
+  m <- capture_messages(check_default_data_path())
+  expect_match(m, "You don't appear to have a defined location for storing Portal data.", all = FALSE)
+  expect_match(m, "Call .+ if you wish to set the default data path.", all = FALSE)
+  expect_match(m, "Portal data will be downloaded into .+ otherwise.", all = FALSE)
+
+  expect_error(use_default_data_path())
+
+  data_path <- tempdir()
+  expect_error(m <- capture_output(use_default_data_path(data_path)), NA)
+  expect_match(m, "Call `usethis::edit_r_environ\\(\\)` to open '.Renviron'")
+  expect_match(m, "Store your data path with a line like:")
+  expect_match(m, "PORTALR_DATA_PATH=")
+  expect_match(m, "Make sure '.Renviron' ends with a newline!")
+})
+
+test_that("default data path functions work if set", {
+ Sys.setenv("PORTALR_DATA_PATH" = tempdir())
+  expect_true(check_default_data_path())
+  expect_equal(get_default_data_path(), tempdir())
+})
